<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl_NL" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <location filename="../src/AboutView.cpp" line="21"/>
        <source>There&apos;s life outside the browser!</source>
        <translation>Er is leven buiten de browser!</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="22"/>
        <source>Version %1</source>
        <translation>Versie %1</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="25"/>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 is Gratis Software maar de ontwikkeling is kostbare tijd.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="26"/>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;Doneer&lt;/a&gt; om bij te dragen aan de ontwikkeling van %2.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="29"/>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Raporteer fouten en stuur je ideën naar %1</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="33"/>
        <source>Icon designed by %1.</source>
        <translation>Icon ontworpen door %1.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="34"/>
        <source>Compact mode contributed by %1.</source>
        <translation>Compact mode aangedragen door %1.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="35"/>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>HTTP proxy ondersteuning aangedragen door %1.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="38"/>
        <source>Translated by %1</source>
        <translation>Vertaald door %1</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="66"/>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Uitgebracht onder de &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="78"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <location filename="../src/AboutView.h" line="18"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="../src/AboutView.h" line="20"/>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Wat u altijd al had willen weten over %1 maar nooit heeft durven vragen</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <location filename="../src/searchlineedit.cpp" line="56"/>
        <source>Clear</source>
        <translation>Wis</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <location filename="../src/downloaditem.cpp" line="295"/>
        <source>bytes</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="298"/>
        <source>KB</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="301"/>
        <source>MB</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="317"/>
        <source>bytes/sec</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="320"/>
        <source>KB/sec</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="323"/>
        <source>MB/sec</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="329"/>
        <source>seconds</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="332"/>
        <source>minutes</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="335"/>
        <source>%4 %5 remaining</source>
        <translation/>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <location filename="../src/downloadmanager.cpp" line="47"/>
        <source>This is just the demo version of %1.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloadmanager.cpp" line="49"/>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloadmanager.cpp" line="53"/>
        <source>Continue</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloadmanager.cpp" line="54"/>
        <source>Get the full version</source>
        <translation/>
    </message>
    <message numerus="yes">
        <location filename="../src/downloadmanager.cpp" line="126"/>
        <source>%n Download(s)</source>
        <translation><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <location filename="../src/downloadsettings.cpp" line="14"/>
        <source>Change location...</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="38"/>
        <source>Choose the download location</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="49"/>
        <source>Download location changed.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="51"/>
        <source>Current downloads will still go in the previous location.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="63"/>
        <source>Downloading to: %1</source>
        <translation/>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <location filename="../src/downloadview.cpp" line="18"/>
        <location filename="../src/downloadview.h" line="22"/>
        <source>Downloads</source>
        <translation/>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="16"/>
        <source>Play</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="17"/>
        <source>Pause</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="18"/>
        <source>Play/Pause</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="19"/>
        <source>Stop</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="20"/>
        <source>Stop playing after current track</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="21"/>
        <source>Next track</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="22"/>
        <source>Previous track</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="23"/>
        <source>Increase volume</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="24"/>
        <source>Decrease volume</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="25"/>
        <source>Mute</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="26"/>
        <source>Seek forward</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="27"/>
        <source>Seek backward</source>
        <translation/>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <location filename="../src/ListModel.cpp" line="47"/>
        <source>Searching...</source>
        <translation>Bezig met Zoeken...</translation>
    </message>
    <message>
        <location filename="../src/ListModel.cpp" line="48"/>
        <source>Show %1 More</source>
        <translation>Laat %1 meer zien</translation>
    </message>
    <message>
        <location filename="../src/ListModel.cpp" line="49"/>
        <source>No videos</source>
        <translation>Geen video&apos;s</translation>
    </message>
    <message>
        <location filename="../src/ListModel.cpp" line="50"/>
        <source>No more videos</source>
        <translation>Geen video&apos;s meer</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <location filename="../src/loadingwidget.cpp" line="71"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/MainWindow.cpp" line="105"/>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="106"/>
        <source>Stop playback and go back to the search view</source>
        <translation>Stop het afspelen en ga terug naar het zoek overzicht</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="112"/>
        <source>S&amp;kip</source>
        <translation>&amp;Overslaan</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="113"/>
        <source>Skip to the next video</source>
        <translation>Overslaan en naar de volgende video</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="119"/>
        <location filename="../src/MainWindow.cpp" line="644"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pauzeer</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="120"/>
        <location filename="../src/MainWindow.cpp" line="645"/>
        <source>Pause playback</source>
        <translation>Pauzeer afspelen</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="126"/>
        <location filename="../src/MainWindow.cpp" line="728"/>
        <source>&amp;Full Screen</source>
        <translation>&amp;Volledig scherm</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="127"/>
        <source>Go full screen</source>
        <translation>Ga naar volledig scherm</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="136"/>
        <source>&amp;Compact mode</source>
        <translation>&amp;Compacte modus</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="137"/>
        <source>Hide the playlist and the toolbar</source>
        <translation>Verberg de overzichtslijst en de werkbalk</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="145"/>
        <source>Open the &amp;YouTube page</source>
        <translation>Open de &amp;YouTube pagina</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="146"/>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Ga naar de YouTube video pagina en pauzeer het afspelen</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="152"/>
        <source>Copy the YouTube &amp;link</source>
        <translation>Kopieer de YouTube &amp;link</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="153"/>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Kopieer de huidige YouTube link naar het klembord</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="159"/>
        <source>Copy the video stream &amp;URL</source>
        <translation>Kopieer de video stream &amp;URL</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="160"/>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopieer de huidige video stream URL naar het klembord</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="166"/>
        <source>&amp;Remove</source>
        <translation>&amp;Verwijder</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="167"/>
        <source>Remove the selected videos from the playlist</source>
        <translation>Verwijder de geselecteerde video&apos;s van de afspeellijst</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="173"/>
        <source>Move &amp;Up</source>
        <translation>Verplaats &amp;Omhoog</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="174"/>
        <source>Move up the selected videos in the playlist</source>
        <translation>Verplaats de geselecteerde video&apos;s in de afspeellijst naar boven</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="180"/>
        <source>Move &amp;Down</source>
        <translation>Verplaats &amp;Omlaag</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="181"/>
        <source>Move down the selected videos in the playlist</source>
        <translation>Verplaats de geselecteerde video&apos;s in de afspeelijst naar beneden</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="187"/>
        <source>&amp;Clear recent searches</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="192"/>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Wis de zoek geschiedenis. Dit kan niet ongedaan worden gemaakt.</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="197"/>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="199"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="200"/>
        <source>Bye</source>
        <translation>Tot ziens</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="204"/>
        <source>&amp;Website</source>
        <translation>&amp;Website</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="206"/>
        <source>%1 on the Web</source>
        <translation>%1 op het internet</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="210"/>
        <source>Make a &amp;donation</source>
        <translation>Maak een &amp;donatie</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="211"/>
        <source>Please support the continued development of %1</source>
        <translation>Ondersteun de ontwikkeling van %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="215"/>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="217"/>
        <source>Info about %1</source>
        <translation>Informatie over %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="225"/>
        <source>Search</source>
        <translation>Zoek</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="244"/>
        <source>Mute volume</source>
        <translation>Geen volume</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="246"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="277"/>
        <location filename="../src/MainWindow.cpp" line="959"/>
        <source>&amp;Downloads</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="278"/>
        <source>Show details about video downloads</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="286"/>
        <source>&amp;Download</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="287"/>
        <source>Download the current video</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="328"/>
        <source>&amp;Application</source>
        <translation>&amp;Applicatie</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="336"/>
        <source>&amp;Playlist</source>
        <translation>&amp;Afspeellijst</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="343"/>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="362"/>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="439"/>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Druk op %1 voor meer volume en op %2 voor minder</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="578"/>
        <location filename="../src/MainWindow.cpp" line="584"/>
        <source>Opening %1</source>
        <translation>Openen van %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="597"/>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="598"/>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="601"/>
        <source>Close and cancel download</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="602"/>
        <source>Wait for download to finish</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="635"/>
        <source>Fatal error: %1</source>
        <translation>Fatale fout: %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="637"/>
        <source>Error: %1</source>
        <translation>Fout: %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="660"/>
        <source>&amp;Play</source>
        <translation>&amp;Afspelen</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="661"/>
        <source>Resume playback</source>
        <translation>Afspelen hervatten</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="751"/>
        <source>Exit &amp;Full Screen</source>
        <translation>Sluit &amp;Volledig Scherm</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="834"/>
        <source>Remaining time: %1</source>
        <translation>Overige tijd: %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="892"/>
        <source>Volume at %1%</source>
        <translation>Volume op %1%</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="898"/>
        <source>Volume is muted</source>
        <translation>Volume is uit</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="901"/>
        <source>Volume is unmuted</source>
        <translation>Volume is aan</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="908"/>
        <source>Maximum video definition set to %1</source>
        <translation>Maximale video defititie staat op %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="944"/>
        <source>Your privacy is now safe</source>
        <translation>Uw privacy is nu veilig</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="960"/>
        <source>Downloads complete</source>
        <translation/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <location filename="../src/MediaView.cpp" line="33"/>
        <source>Most relevant</source>
        <translation>Meest relevant</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="40"/>
        <source>Most recent</source>
        <translation>Meest recent</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="47"/>
        <source>Most viewed</source>
        <translation>Meest bekeken</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="489"/>
        <source>You can now paste the YouTube link into another application</source>
        <translation>U kunt nu uw YouTube link kopieeren naar een andere applicatie</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="497"/>
        <source>You can now paste the video stream URL into another application</source>
        <translation>U kunt nu uw video stream URL kopieeren naar een andere applicatie</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="498"/>
        <source>The link will be valid only for a limited time.</source>
        <translation>De link zal maar een beperkte tijd geldig zijn.</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="594"/>
        <source>This is just the demo version of %1.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="595"/>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="598"/>
        <source>Continue</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="599"/>
        <source>Get the full version</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="625"/>
        <source>Downloading %1</source>
        <translation/>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <location filename="../src/networkaccess.cpp" line="258"/>
        <source>Network error: %1</source>
        <translation>Netwerk fout %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="156"/>
        <source>%1 views</source>
        <translation>%1 bekeken</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="286"/>
        <source>%1 of %2 (%3) — %4</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="293"/>
        <source>Preparing</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="295"/>
        <source>Failed</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="297"/>
        <source>Completed</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="299"/>
        <source>Stopped</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="335"/>
        <source>Stop downloading</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="345"/>
        <source>Show in %1</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="347"/>
        <source>Open parent folder</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="356"/>
        <source>Restart downloading</source>
        <translation/>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <location filename="../src/searchlineedit.cpp" line="177"/>
        <source>Search</source>
        <translation>Zoek</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <location filename="../src/SearchView.cpp" line="74"/>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Welkom bij &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="41"/>
        <source>Get the full version</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="88"/>
        <source>Enter</source>
        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
        <translation/>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="93"/>
        <source>a keyword</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="94"/>
        <source>a channel</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="99"/>
        <source>to start watching videos.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="124"/>
        <source>Watch</source>
        <translation>Bekijk</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="141"/>
        <source>Recent keywords</source>
        <translation>Recente zoekopdrachten</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="159"/>
        <source>Recent channels</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="358"/>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Een nieuwere versie van %1 is beschikbaar.&lt;a href=&apos;%2&apos;&gt;Update naar versie %3&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/SearchView.h" line="35"/>
        <source>Make yourself comfortable</source>
        <translation>Ga er lekker voor zitten</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <location filename="../src/video.cpp" line="186"/>
        <source>Cannot get video stream for %1</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/video.cpp" line="204"/>
        <source>Network error: %1 for %2</source>
        <translation>Netwerk fout %1 voor %2</translation>
    </message>
</context>
</TS>